@@ -12,7 +12,7 @@ lkd_make_request <- function(
     req_url_path_append(endpoint) %>%
     req_url_path_append(path_append) %>%
     req_auth_bearer_token(lkd_get_token()$access_token) %>%
-    req_url_query(!!!params) %>%
+    req_url_query(!!!params, .multi = "explode") %>%
     req_headers(
       'Linkedin-Version' = getOption('lkd.api_version')
     ) %>%
